## CSS - Demos - Navs Tabs

<script type="module" src="/web_components/js/css/demos/WebC__CSS__Demo__Navs_Tabs.mjs"></script>

<webc-container>
    <webc-css-demo-navs-tabs        ></webc-css-demo-navs-tabs> 
    <webc-css-demo-navs-tabs no-css ></webc-css-demo-navs-tabs>
    
</webc-container>